@@ -47,7 +47,7 @@ class ClusterTemplate(base.APIBase):
     name = wtypes.StringType(min_length=1, max_length=255)
     """The name of the ClusterTemplate"""
 
-    coe = wtypes.Enum(str, *fields.BayType.ALL, mandatory=True)
+    coe = wtypes.Enum(str, *fields.ClusterType.ALL, mandatory=True)
     """The Container Orchestration Engine for this clustertemplate"""
 
     image_id = wsme.wsattr(wtypes.StringType(min_length=1, max_length=255),
@@ -142,7 +142,7 @@ class ClusterTemplate(base.APIBase):
 
     def __init__(self, **kwargs):
         self.fields = []
-        for field in objects.BayModel.fields:
+        for field in objects.ClusterTemplate.fields:
             # Skip fields we do not expose.
             if not hasattr(self, field):
                 continue
@@ -185,7 +185,7 @@ class ClusterTemplate(base.APIBase):
             docker_volume_size=25,
             docker_storage_driver='devicemapper',
             cluster_distro='fedora-atomic',
-            coe=fields.BayType.KUBERNETES,
+            coe=fields.ClusterType.KUBERNETES,
             http_proxy='http://proxy.com:123',
             https_proxy='https://proxy.com:123',
             no_proxy='192.168.0.1,192.168.0.2,192.168.0.3',
@@ -255,13 +255,12 @@ class ClusterTemplatesController(base.Controller):
 
         marker_obj = None
         if marker:
-            marker_obj = objects.BayModel.get_by_uuid(pecan.request.context,
-                                                      marker)
+            marker_obj = objects.ClusterTemplate.get_by_uuid(
+                pecan.request.context, marker)
 
-        cluster_templates = objects.BayModel.list(pecan.request.context, limit,
-                                                  marker_obj,
-                                                  sort_key=sort_key,
-                                                  sort_dir=sort_dir)
+        cluster_templates = objects.ClusterTemplate.list(
+            pecan.request.context, limit, marker_obj, sort_key=sort_key,
+            sort_dir=sort_dir)
 
         return ClusterTemplateCollection.convert_with_links(cluster_templates,
                                                             limit,
@@ -319,7 +318,7 @@ class ClusterTemplatesController(base.Controller):
         ClusterTemplate.
         """
         context = pecan.request.context
-        cluster_template = api_utils.get_resource('BayModel',
+        cluster_template = api_utils.get_resource('ClusterTemplate',
                                                   cluster_template_ident)
         if not cluster_template.public:
             policy.enforce(context, 'clustertemplate:get', cluster_template,
@@ -360,8 +359,8 @@ class ClusterTemplatesController(base.Controller):
         name = arg_name or self._generate_name_for_cluster_template(context)
         cluster_template_dict['name'] = name
 
-        new_cluster_template = objects.BayModel(context,
-                                                **cluster_template_dict)
+        new_cluster_template = objects.ClusterTemplate(context,
+                                                       **cluster_template_dict)
         new_cluster_template.create()
         # Set the HTTP Location Header
         pecan.response.location = link.build_url('clustertemplates',
@@ -382,7 +381,7 @@ class ClusterTemplatesController(base.Controller):
         ClusterTemplate.
         """
         context = pecan.request.context
-        cluster_template = api_utils.get_resource('BayModel',
+        cluster_template = api_utils.get_resource('ClusterTemplate',
                                                   cluster_template_ident)
         policy.enforce(context, 'clustertemplate:update', cluster_template,
                        action='clustertemplate:update')
@@ -404,7 +403,7 @@ class ClusterTemplatesController(base.Controller):
                 raise exception.ClusterTemplatePublishDenied()
 
         # Update only the fields that have changed
-        for field in objects.BayModel.fields:
+        for field in objects.ClusterTemplate.fields:
             try:
                 patch_val = getattr(new_cluster_template, field)
             except AttributeError:
@@ -426,7 +425,7 @@ class ClusterTemplatesController(base.Controller):
          ClusterTemplate.
         """
         context = pecan.request.context
-        cluster_template = api_utils.get_resource('BayModel',
+        cluster_template = api_utils.get_resource('ClusterTemplate',
                                                   cluster_template_ident)
         policy.enforce(context, 'clustertemplate:delete', cluster_template,
                        action='clustertemplate:delete')
