@@ -44,8 +44,8 @@ TRANSPORT_ALIASES = {
 periodic_opts = [
     cfg.BoolOpt('periodic_global_stack_list',
                 default=False,
-                help="List Heat stacks globally when syncing bays. "
-                     "Default is to do retrieve each bay's stack  "
+                help="List Heat stacks globally when syncing clusters. "
+                     "Default is to do retrieve each cluster's stack  "
                      "individually. Reduces number of requests against "
                      "Heat API if enabled but requires changes to Heat's "
                      "policy.json."),
