@@ -12,20 +12,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from magnum.objects import bay
-from magnum.objects import baymodel
 from magnum.objects import certificate
+from magnum.objects import cluster
+from magnum.objects import cluster_template
 from magnum.objects import magnum_service
 from magnum.objects import x509keypair
 
 
-Bay = bay.Bay
-BayModel = baymodel.BayModel
+Cluster = cluster.Cluster
+ClusterTemplate = cluster_template.ClusterTemplate
 MagnumService = magnum_service.MagnumService
 X509KeyPair = x509keypair.X509KeyPair
 Certificate = certificate.Certificate
-__all__ = (Bay,
-           BayModel,
+__all__ = (Cluster,
+           ClusterTemplate,
            MagnumService,
            X509KeyPair,
            Certificate)
