@@ -24,7 +24,7 @@ import magnum.common.exception
 import magnum.common.service
 import magnum.common.x509.config
 import magnum.conductor.config
-import magnum.conductor.handlers.bay_conductor
+import magnum.conductor.handlers.cluster_conductor
 import magnum.db
 import magnum.drivers.common.template_def
 
@@ -38,7 +38,7 @@ def list_opts():
                          magnum.common.service.service_opts,
                          )),
         ('api', magnum.api.app.API_SERVICE_OPTS),
-        ('bay', magnum.drivers.common.template_def.template_def_opts),
+        ('cluster', magnum.drivers.common.template_def.template_def_opts),
         ('conductor', magnum.conductor.config.SERVICE_OPTS),
         ('database', magnum.db.sql_opts),
         ('docker', magnum.common.docker_utils.docker_opts),
@@ -51,12 +51,13 @@ def list_opts():
         ('nova_client', magnum.common.clients.nova_client_opts),
         ('neutron_client', magnum.common.clients.neutron_client_opts),
         ('x509', magnum.common.x509.config.x509_opts),
-        ('bay_heat', magnum.conductor.handlers.bay_conductor.bay_heat_opts),
+        ('cluster_heat',
+            magnum.conductor.handlers.cluster_conductor.cluster_heat_opts),
         ('certificates',
             itertools.chain(magnum.common.cert_manager.cert_manager_opts,
                             local_cert_manager.local_cert_manager_opts,
                             )),
-        ('baymodel', magnum.api.validation.baymodel_opts),
+        ('cluster_template', magnum.api.validation.cluster_template_opts),
         ('keystone_auth', magnum.common.keystone.keystone_auth_opts),
         ('docker_registry',
          magnum.drivers.common.template_def.docker_registry_opts)
