@@ -28,99 +28,65 @@ from magnum import objects
 from magnum.tests.unit.db import utils as db_utils
 
 
-def get_test_baymodel(context, **kw):
-    """Return a BayModel object with appropriate attributes.
-
-    NOTE: The object leaves the attributes marked as changed, such
-    that a create() could be used to commit it to the DB.
-    """
-    db_baymodel = db_utils.get_test_baymodel(**kw)
-    # Let DB generate ID if it isn't specified explicitly
-    if 'id' not in kw:
-        del db_baymodel['id']
-    baymodel = objects.BayModel(context)
-    for key in db_baymodel:
-        setattr(baymodel, key, db_baymodel[key])
-    return baymodel
-
-
-def create_test_baymodel(context, **kw):
-    """Create and return a test baymodel object.
-
-    Create a baymodel in the DB and return a BayModel object with appropriate
-    attributes.
-    """
-    baymodel = get_test_baymodel(context, **kw)
-    try:
-        baymodel.create()
-    except exception.ClusterTemplateAlreadyExists:
-        baymodel = objects.BayModel.get(context, baymodel.uuid)
-    return baymodel
-
-
-def get_test_bay(context, **kw):
-    """Return a Bay object with appropriate attributes.
-
-    NOTE: The object leaves the attributes marked as changed, such
-    that a create() could be used to commit it to the DB.
-    """
-    db_bay = db_utils.get_test_bay(**kw)
-    # Let DB generate ID if it isn't specified explicitly
-    if 'id' not in kw:
-        del db_bay['id']
-    bay = objects.Bay(context)
-    for key in db_bay:
-        setattr(bay, key, db_bay[key])
-    return bay
-
-
-def create_test_bay(context, **kw):
-    """Create and return a test bay object.
-
-    Create a bay in the DB and return a Bay object with appropriate
-    attributes.
-    """
-    bay = get_test_bay(context, **kw)
-    create_test_baymodel(context, uuid=bay['baymodel_id'],
-                         coe=kw.get('coe', 'swarm'))
-    bay.create()
-    return bay
-
-
 def get_test_cluster_template(context, **kw):
     """Return a ClusterTemplate object with appropriate attributes.
 
-    NOTE: Object model is the same for ClusterTemplate and
-    BayModel
+    NOTE: The object leaves the attributes marked as changed, such
+    that a create() could be used to commit it to the DB.
     """
-    return get_test_baymodel(context, **kw)
+    db_cluster_template = db_utils.get_test_cluster_template(**kw)
+    cluster_template = objects.ClusterTemplate(context)
+    # Let DB generate ID if it isn't specified explicitly
+    if 'id' not in kw:
+        del db_cluster_template['id']
+
+    for key in db_cluster_template:
+        setattr(cluster_template, key, db_cluster_template[key])
+    return cluster_template
 
 
 def create_test_cluster_template(context, **kw):
     """Create and return a test ClusterTemplate object.
 
-    NOTE: Object model is the same for ClusterTemplate and
-    BayModel
+    Create a ClusterTemplate in the DB and return a ClusterTemplate object
+    with appropriate attributes.
     """
-    return create_test_baymodel(context, **kw)
+    cluster_template = get_test_cluster_template(context, **kw)
+    try:
+        cluster_template.create()
+    except exception.ClusterTemplateAlreadyExists:
+        cluster_template = objects.ClusterTemplate.get(context,
+                                                       cluster_template.uuid)
+    return cluster_template
 
 
 def get_test_cluster(context, **kw):
     """Return a Cluster object with appropriate attributes.
 
-    NOTE: Object model is the same for Cluster and
-    Bay
+    NOTE: The object leaves the attributes marked as changed, such
+    that a create() could be used to commit it to the DB.
     """
-    return get_test_bay(context, **kw)
+    db_cluster = db_utils.get_test_cluster(**kw)
+    # Let DB generate ID if it isn't specified explicitly
+    if 'id' not in kw:
+        del db_cluster['id']
+    cluster = objects.Cluster(context)
+    for key in db_cluster:
+        setattr(cluster, key, db_cluster[key])
+    return cluster
 
 
 def create_test_cluster(context, **kw):
-    """Create and return a test cluster object.
+    """Create and return a test Cluster object.
 
-    NOTE: Object model is the same for Cluster and
-    Bay
+    Create a Cluster in the DB and return a Cluster object with appropriate
+    attributes.
     """
-    return create_test_bay(context, **kw)
+    cluster = get_test_cluster(context, **kw)
+    create_test_cluster_template(context, uuid=cluster['cluster_template_id'],
+                                 coe=kw.get('coe', 'swarm'))
+    cluster.create()
+    return cluster
 
 
 def get_test_x509keypair(context, **kw):
