@@ -19,7 +19,7 @@ from magnum.common import context
 from magnum.common.rpc_service import CONF
 from magnum.db.sqlalchemy import api as dbapi
 from magnum import objects
-from magnum.objects.fields import BayStatus as bay_status
+from magnum.objects.fields import ClusterStatus as cluster_status
 from magnum.service import periodic
 from magnum.tests import base
 from magnum.tests.unit.db import utils
@@ -38,7 +38,7 @@ class PeriodicTestCase(base.TestCase):
 
         ctx = context.make_admin_context()
 
-        # Can be identical for all bays.
+        # Can be identical for all clusters.
         trust_attrs = {
             'trustee_username': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'trustee_password': 'ain7einaebooVaig6d',
@@ -46,40 +46,43 @@ class PeriodicTestCase(base.TestCase):
             }
 
         trust_attrs.update({'id': 1, 'stack_id': '11',
-                           'status': bay_status.CREATE_IN_PROGRESS})
-        bay1 = utils.get_test_bay(**trust_attrs)
+                           'status': cluster_status.CREATE_IN_PROGRESS})
+        cluster1 = utils.get_test_cluster(**trust_attrs)
         trust_attrs.update({'id': 2, 'stack_id': '22',
-                           'status': bay_status.DELETE_IN_PROGRESS})
-        bay2 = utils.get_test_bay(**trust_attrs)
+                           'status': cluster_status.DELETE_IN_PROGRESS})
+        cluster2 = utils.get_test_cluster(**trust_attrs)
         trust_attrs.update({'id': 3, 'stack_id': '33',
-                           'status': bay_status.UPDATE_IN_PROGRESS})
-        bay3 = utils.get_test_bay(**trust_attrs)
+                           'status': cluster_status.UPDATE_IN_PROGRESS})
+        cluster3 = utils.get_test_cluster(**trust_attrs)
         trust_attrs.update({'id': 4, 'stack_id': '44',
-                           'status': bay_status.CREATE_COMPLETE})
-        bay4 = utils.get_test_bay(**trust_attrs)
+                           'status': cluster_status.CREATE_COMPLETE})
+        cluster4 = utils.get_test_cluster(**trust_attrs)
         trust_attrs.update({'id': 5, 'stack_id': '55',
-                           'status': bay_status.ROLLBACK_IN_PROGRESS})
-        bay5 = utils.get_test_bay(**trust_attrs)
+                           'status': cluster_status.ROLLBACK_IN_PROGRESS})
+        cluster5 = utils.get_test_cluster(**trust_attrs)
 
-        self.bay1 = objects.Bay(ctx, **bay1)
-        self.bay2 = objects.Bay(ctx, **bay2)
-        self.bay3 = objects.Bay(ctx, **bay3)
-        self.bay4 = objects.Bay(ctx, **bay4)
-        self.bay5 = objects.Bay(ctx, **bay5)
+        self.cluster1 = objects.Cluster(ctx, **cluster1)
+        self.cluster2 = objects.Cluster(ctx, **cluster2)
+        self.cluster3 = objects.Cluster(ctx, **cluster3)
+        self.cluster4 = objects.Cluster(ctx, **cluster4)
+        self.cluster5 = objects.Cluster(ctx, **cluster5)
 
-    @mock.patch.object(objects.Bay, 'list')
+    @mock.patch.object(objects.Cluster, 'list')
     @mock.patch('magnum.common.clients.OpenStackClients')
-    @mock.patch.object(dbapi.Connection, 'destroy_bay')
-    @mock.patch.object(dbapi.Connection, 'update_bay')
-    def test_sync_bay_status_changes(self, mock_db_update, mock_db_destroy,
-                                     mock_oscc, mock_bay_list):
+    @mock.patch.object(dbapi.Connection, 'destroy_cluster')
+    @mock.patch.object(dbapi.Connection, 'update_cluster')
+    def test_sync_cluster_status_changes(self, mock_db_update, mock_db_destroy,
+                                         mock_oscc, mock_cluster_list):
         mock_heat_client = mock.MagicMock()
-        stack1 = fake_stack(id='11', stack_status=bay_status.CREATE_COMPLETE,
-                            stack_status_reason='fake_reason_11')
-        stack3 = fake_stack(id='33', stack_status=bay_status.UPDATE_COMPLETE,
-                            stack_status_reason='fake_reason_33')
-        stack5 = fake_stack(id='55', stack_status=bay_status.ROLLBACK_COMPLETE,
-                            stack_status_reason='fake_reason_55')
+        stack1 = fake_stack(
+            id='11', stack_status=cluster_status.CREATE_COMPLETE,
+            stack_status_reason='fake_reason_11')
+        stack3 = fake_stack(
+            id='33', stack_status=cluster_status.UPDATE_COMPLETE,
+            stack_status_reason='fake_reason_33')
+        stack5 = fake_stack(
+            id='55', stack_status=cluster_status.ROLLBACK_COMPLETE,
+            stack_status_reason='fake_reason_55')
         mock_heat_client.stacks.list.return_value = [stack1, stack3, stack5]
         get_stacks = {'11': stack1, '33': stack3, '55': stack5}
 
@@ -91,35 +94,36 @@ class PeriodicTestCase(base.TestCase):
         mock_heat_client.stacks.get.side_effect = stack_get_sideefect
         mock_osc = mock_oscc.return_value
         mock_osc.heat.return_value = mock_heat_client
-        mock_bay_list.return_value = [self.bay1, self.bay2, self.bay3,
-                                      self.bay5]
+        mock_cluster_list.return_value = [self.cluster1, self.cluster2,
+                                          self.cluster3, self.cluster5]
 
         mock_keystone_client = mock.MagicMock()
         mock_keystone_client.client.project_id = "fake_project"
         mock_osc.keystone.return_value = mock_keystone_client
 
-        periodic.MagnumPeriodicTasks(CONF).sync_bay_status(None)
+        periodic.MagnumPeriodicTasks(CONF).sync_cluster_status(None)
 
-        self.assertEqual(bay_status.CREATE_COMPLETE, self.bay1.status)
-        self.assertEqual('fake_reason_11', self.bay1.status_reason)
-        mock_db_destroy.assert_called_once_with(self.bay2.uuid)
-        self.assertEqual(bay_status.UPDATE_COMPLETE, self.bay3.status)
-        self.assertEqual('fake_reason_33', self.bay3.status_reason)
-        self.assertEqual(bay_status.ROLLBACK_COMPLETE, self.bay5.status)
-        self.assertEqual('fake_reason_55', self.bay5.status_reason)
+        self.assertEqual(cluster_status.CREATE_COMPLETE, self.cluster1.status)
+        self.assertEqual('fake_reason_11', self.cluster1.status_reason)
+        mock_db_destroy.assert_called_once_with(self.cluster2.uuid)
+        self.assertEqual(cluster_status.UPDATE_COMPLETE, self.cluster3.status)
+        self.assertEqual('fake_reason_33', self.cluster3.status_reason)
+        self.assertEqual(cluster_status.ROLLBACK_COMPLETE,
+                         self.cluster5.status)
+        self.assertEqual('fake_reason_55', self.cluster5.status_reason)
 
-    @mock.patch.object(objects.Bay, 'list')
+    @mock.patch.object(objects.Cluster, 'list')
     @mock.patch('magnum.common.clients.OpenStackClients')
-    def test_sync_auth_fail(self, mock_oscc, mock_bay_list):
-        """Tests handling for unexpected exceptions in _get_bay_stacks()
+    def test_sync_auth_fail(self, mock_oscc, mock_cluster_list):
+        """Tests handling for unexpected exceptions in _get_cluster_stacks()
 
         It does this by raising an a HTTPUnauthorized exception in Heat client.
         The affected stack thus missing from the stack list should not lead to
-        bay state changing in this case. Likewise, subsequent bays should still
-        change state, despite the affected bay being skipped.
+        cluster state changing in this case. Likewise, subsequent clusters
+        should still change state, despite the affected cluster being skipped.
         """
         stack1 = fake_stack(id='11',
-                            stack_status=bay_status.CREATE_COMPLETE)
+                            stack_status=cluster_status.CREATE_COMPLETE)
 
         mock_heat_client = mock.MagicMock()
 
@@ -130,23 +134,25 @@ class PeriodicTestCase(base.TestCase):
         mock_heat_client.stacks.list.return_value = [stack1]
         mock_osc = mock_oscc.return_value
         mock_osc.heat.return_value = mock_heat_client
-        mock_bay_list.return_value = [self.bay1]
-        periodic.MagnumPeriodicTasks(CONF).sync_bay_status(None)
+        mock_cluster_list.return_value = [self.cluster1]
+        periodic.MagnumPeriodicTasks(CONF).sync_cluster_status(None)
 
-        self.assertEqual(bay_status.CREATE_IN_PROGRESS, self.bay1.status)
+        self.assertEqual(cluster_status.CREATE_IN_PROGRESS,
+                         self.cluster1.status)
 
-    @mock.patch.object(objects.Bay, 'list')
+    @mock.patch.object(objects.Cluster, 'list')
     @mock.patch('magnum.common.clients.OpenStackClients')
-    def test_sync_bay_status_not_changes(self, mock_oscc, mock_bay_list):
+    def test_sync_cluster_status_not_changes(self, mock_oscc,
+                                             mock_cluster_list):
         mock_heat_client = mock.MagicMock()
         stack1 = fake_stack(id='11',
-                            stack_status=bay_status.CREATE_IN_PROGRESS)
+                            stack_status=cluster_status.CREATE_IN_PROGRESS)
         stack2 = fake_stack(id='22',
-                            stack_status=bay_status.DELETE_IN_PROGRESS)
+                            stack_status=cluster_status.DELETE_IN_PROGRESS)
         stack3 = fake_stack(id='33',
-                            stack_status=bay_status.UPDATE_IN_PROGRESS)
+                            stack_status=cluster_status.UPDATE_IN_PROGRESS)
         stack5 = fake_stack(id='55',
-                            stack_status=bay_status.ROLLBACK_IN_PROGRESS)
+                            stack_status=cluster_status.ROLLBACK_IN_PROGRESS)
         get_stacks = {'11': stack1, '22': stack2, '33': stack3, '55': stack5}
 
         def stack_get_sideefect(arg):
@@ -159,63 +165,69 @@ class PeriodicTestCase(base.TestCase):
                                                      stack5]
         mock_osc = mock_oscc.return_value
         mock_osc.heat.return_value = mock_heat_client
-        mock_bay_list.return_value = [self.bay1, self.bay2, self.bay3,
-                                      self.bay5]
-        periodic.MagnumPeriodicTasks(CONF).sync_bay_status(None)
+        mock_cluster_list.return_value = [self.cluster1, self.cluster2,
+                                          self.cluster3, self.cluster5]
+        periodic.MagnumPeriodicTasks(CONF).sync_cluster_status(None)
 
-        self.assertEqual(bay_status.CREATE_IN_PROGRESS, self.bay1.status)
-        self.assertEqual(bay_status.DELETE_IN_PROGRESS, self.bay2.status)
-        self.assertEqual(bay_status.UPDATE_IN_PROGRESS, self.bay3.status)
-        self.assertEqual(bay_status.ROLLBACK_IN_PROGRESS, self.bay5.status)
+        self.assertEqual(cluster_status.CREATE_IN_PROGRESS,
+                         self.cluster1.status)
+        self.assertEqual(cluster_status.DELETE_IN_PROGRESS,
+                         self.cluster2.status)
+        self.assertEqual(cluster_status.UPDATE_IN_PROGRESS,
+                         self.cluster3.status)
+        self.assertEqual(cluster_status.ROLLBACK_IN_PROGRESS,
+                         self.cluster5.status)
 
-    @mock.patch.object(objects.Bay, 'list')
+    @mock.patch.object(objects.Cluster, 'list')
     @mock.patch('magnum.common.clients.OpenStackClients')
-    @mock.patch.object(dbapi.Connection, 'destroy_bay')
-    @mock.patch.object(dbapi.Connection, 'update_bay')
-    def test_sync_bay_status_heat_not_found(self, mock_db_update,
-                                            mock_db_destroy, mock_oscc,
-                                            mock_bay_list):
+    @mock.patch.object(dbapi.Connection, 'destroy_cluster')
+    @mock.patch.object(dbapi.Connection, 'update_cluster')
+    def test_sync_cluster_status_heat_not_found(self, mock_db_update,
+                                                mock_db_destroy, mock_oscc,
+                                                mock_cluster_list):
         mock_heat_client = mock.MagicMock()
         mock_heat_client.stacks.list.return_value = []
         mock_osc = mock_oscc.return_value
         mock_osc.heat.return_value = mock_heat_client
-        mock_bay_list.return_value = [self.bay1, self.bay2, self.bay3]
+        mock_cluster_list.return_value = [self.cluster1, self.cluster2,
+                                          self.cluster3]
 
         mock_keystone_client = mock.MagicMock()
         mock_keystone_client.client.project_id = "fake_project"
         mock_osc.keystone.return_value = mock_keystone_client
 
-        periodic.MagnumPeriodicTasks(CONF).sync_bay_status(None)
+        periodic.MagnumPeriodicTasks(CONF).sync_cluster_status(None)
 
-        self.assertEqual(bay_status.CREATE_FAILED, self.bay1.status)
+        self.assertEqual(cluster_status.CREATE_FAILED, self.cluster1.status)
         self.assertEqual('Stack with id 11 not found in Heat.',
-                         self.bay1.status_reason)
-        mock_db_destroy.assert_called_once_with(self.bay2.uuid)
-        self.assertEqual(bay_status.UPDATE_FAILED, self.bay3.status)
+                         self.cluster1.status_reason)
+        mock_db_destroy.assert_called_once_with(self.cluster2.uuid)
+        self.assertEqual(cluster_status.UPDATE_FAILED, self.cluster3.status)
         self.assertEqual('Stack with id 33 not found in Heat.',
-                         self.bay3.status_reason)
+                         self.cluster3.status_reason)
 
     @mock.patch('magnum.conductor.monitors.create_monitor')
-    @mock.patch('magnum.objects.Bay.list')
+    @mock.patch('magnum.objects.Cluster.list')
     @mock.patch('magnum.common.rpc.get_notifier')
     @mock.patch('magnum.common.context.make_admin_context')
-    def test_send_bay_metrics(self, mock_make_admin_context, mock_get_notifier,
-                              mock_bay_list, mock_create_monitor):
+    def test_send_cluster_metrics(self, mock_make_admin_context,
+                                  mock_get_notifier, mock_cluster_list,
+                                  mock_create_monitor):
         """Test if RPC notifier receives the expected message"""
         mock_make_admin_context.return_value = self.context
         notifier = mock.MagicMock()
         mock_get_notifier.return_value = notifier
-        mock_bay_list.return_value = [self.bay1, self.bay2, self.bay3,
-                                      self.bay4]
+        mock_cluster_list.return_value = [self.cluster1, self.cluster2,
+                                          self.cluster3, self.cluster4]
         monitor = mock.MagicMock()
         monitor.get_metric_names.return_value = ['metric1', 'metric2']
         monitor.compute_metric_value.return_value = 30
         monitor.get_metric_unit.return_value = '%'
         mock_create_monitor.return_value = monitor
 
-        periodic.MagnumPeriodicTasks(CONF)._send_bay_metrics(self.context)
+        periodic.MagnumPeriodicTasks(CONF)._send_cluster_metrics(self.context)
 
-        expected_event_type = 'magnum.bay.metrics.update'
+        expected_event_type = 'magnum.cluster.metrics.update'
         expected_metrics = [
             {
                 'name': 'metric1',
@@ -229,9 +241,9 @@ class PeriodicTestCase(base.TestCase):
             },
         ]
         expected_msg = {
-            'user_id': self.bay4.user_id,
-            'project_id': self.bay4.project_id,
-            'resource_id': self.bay4.uuid,
+            'user_id': self.cluster4.user_id,
+            'project_id': self.cluster4.project_id,
+            'resource_id': self.cluster4.uuid,
             'metrics': expected_metrics
         }
 
@@ -240,29 +252,29 @@ class PeriodicTestCase(base.TestCase):
             self.context, expected_event_type, expected_msg)
 
     @mock.patch('magnum.conductor.monitors.create_monitor')
-    @mock.patch('magnum.objects.Bay.list')
+    @mock.patch('magnum.objects.Cluster.list')
     @mock.patch('magnum.common.rpc.get_notifier')
     @mock.patch('magnum.common.context.make_admin_context')
-    def test_send_bay_metrics_compute_metric_raise(
-            self, mock_make_admin_context, mock_get_notifier, mock_bay_list,
-            mock_create_monitor):
+    def test_send_cluster_metrics_compute_metric_raise(
+            self, mock_make_admin_context, mock_get_notifier,
+            mock_cluster_list, mock_create_monitor):
         mock_make_admin_context.return_value = self.context
         notifier = mock.MagicMock()
         mock_get_notifier.return_value = notifier
-        mock_bay_list.return_value = [self.bay4]
+        mock_cluster_list.return_value = [self.cluster4]
         monitor = mock.MagicMock()
         monitor.get_metric_names.return_value = ['metric1', 'metric2']
         monitor.compute_metric_value.side_effect = Exception(
             "error on computing metric")
         mock_create_monitor.return_value = monitor
 
-        periodic.MagnumPeriodicTasks(CONF)._send_bay_metrics(self.context)
+        periodic.MagnumPeriodicTasks(CONF)._send_cluster_metrics(self.context)
 
-        expected_event_type = 'magnum.bay.metrics.update'
+        expected_event_type = 'magnum.cluster.metrics.update'
         expected_msg = {
-            'user_id': self.bay4.user_id,
-            'project_id': self.bay4.project_id,
-            'resource_id': self.bay4.uuid,
+            'user_id': self.cluster4.user_id,
+            'project_id': self.cluster4.project_id,
+            'resource_id': self.cluster4.uuid,
             'metrics': []
         }
         self.assertEqual(1, mock_create_monitor.call_count)
@@ -270,39 +282,39 @@ class PeriodicTestCase(base.TestCase):
             self.context, expected_event_type, expected_msg)
 
     @mock.patch('magnum.conductor.monitors.create_monitor')
-    @mock.patch('magnum.objects.Bay.list')
+    @mock.patch('magnum.objects.Cluster.list')
     @mock.patch('magnum.common.rpc.get_notifier')
     @mock.patch('magnum.common.context.make_admin_context')
-    def test_send_bay_metrics_pull_data_raise(
-            self, mock_make_admin_context, mock_get_notifier, mock_bay_list,
-            mock_create_monitor):
+    def test_send_cluster_metrics_pull_data_raise(
+            self, mock_make_admin_context, mock_get_notifier,
+            mock_cluster_list, mock_create_monitor):
         mock_make_admin_context.return_value = self.context
         notifier = mock.MagicMock()
         mock_get_notifier.return_value = notifier
-        mock_bay_list.return_value = [self.bay4]
+        mock_cluster_list.return_value = [self.cluster4]
         monitor = mock.MagicMock()
         monitor.pull_data.side_effect = Exception("error on pulling data")
         mock_create_monitor.return_value = monitor
 
-        periodic.MagnumPeriodicTasks(CONF)._send_bay_metrics(self.context)
+        periodic.MagnumPeriodicTasks(CONF)._send_cluster_metrics(self.context)
 
         self.assertEqual(1, mock_create_monitor.call_count)
         self.assertEqual(0, notifier.info.call_count)
 
     @mock.patch('magnum.conductor.monitors.create_monitor')
-    @mock.patch('magnum.objects.Bay.list')
+    @mock.patch('magnum.objects.Cluster.list')
     @mock.patch('magnum.common.rpc.get_notifier')
     @mock.patch('magnum.common.context.make_admin_context')
-    def test_send_bay_metrics_monitor_none(
-            self, mock_make_admin_context, mock_get_notifier, mock_bay_list,
-            mock_create_monitor):
+    def test_send_cluster_metrics_monitor_none(
+            self, mock_make_admin_context, mock_get_notifier,
+            mock_cluster_list, mock_create_monitor):
         mock_make_admin_context.return_value = self.context
         notifier = mock.MagicMock()
         mock_get_notifier.return_value = notifier
-        mock_bay_list.return_value = [self.bay4]
+        mock_cluster_list.return_value = [self.cluster4]
         mock_create_monitor.return_value = None
 
-        periodic.MagnumPeriodicTasks(CONF)._send_bay_metrics(self.context)
+        periodic.MagnumPeriodicTasks(CONF)._send_cluster_metrics(self.context)
 
         self.assertEqual(1, mock_create_monitor.call_count)
         self.assertEqual(0, notifier.info.call_count)
